@@ -34,6 +34,8 @@
 #include <linux/sched.h>
 #include <linux/ctype.h>
 #include <linux/string.h>
+#include <linux/kthread.h>
+
 #include <linux/capi.h>
 #include <linux/kernelcapi.h>
 #include <linux/isdn/capilli.h>
@@ -79,7 +81,7 @@ static atomic_t			scheduler_enabled	= ATOMIC_INIT(1);
 static atomic_t			got_kicked		= ATOMIC_INIT(0);
 static atomic_t			crit_count		= ATOMIC_INIT(0);
 static volatile int		hard_error_issued;
-static int			thread_pid		= -1;
+static uintptr_t			thread_pid		= -1;
 static atomic_t			thread_run_flag;
 static atomic_t			thread_capi_flag;
 static volatile unsigned long	stack_lock		= 0;
@@ -688,7 +690,11 @@ static int __kcapi ctr_info (
 \*---------------------------------------------------------------------------*/
 static int ctr_proc_open(struct inode *inode, struct file *file)
 {
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3,10,0)
        return single_open(file, ctr_info, PDE(inode)->data);
+#else
+       return single_open(file, ctr_info, PDE_DATA(inode));
+#endif
 }
 
 const struct file_operations ctr_proc_fops = {
@@ -1256,7 +1262,9 @@ static __attr void __stack scheduler_control (unsigned f) {
 static int scheduler (void * arg) {
 	
 	UNUSED_ARG (arg);
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3,7,0)
 	daemonize (TARGET);
+#endif
 	snprintf (current->comm, 16, "%s_s", TARGET);
 	LOG("Starting scheduler thread '%s'...\n", current->comm);
 	while (atomic_read (&thread_run_flag)) {
@@ -1311,7 +1319,13 @@ int make_thread (void) {
 	atomic_set (&thread_run_flag, 1);
 	atomic_set (&thread_capi_flag, 0);
 	init_waitqueue_head (&capi_wait);
-	thread_pid = kernel_thread (scheduler, NULL, 0);
+
+#if LINUX_VERSION_CODE < KERNEL_VERSION(3,7,0)
+	thread_pid = kernel_thread(scheduler, NULL, 0);
+#else
+	thread_pid = (uintptr_t) kthread_run(scheduler, NULL, "pid");
+#endif
+
 	LOG("Scheduler thread[%d] started.\n", thread_pid);
 	return thread_pid;
 } /* make_thread */
