@@ -112,7 +112,12 @@ static unsigned		lib_heap_size	= 0;
 #define	FENCE2_OK(h,m)	(*(unsigned *)(((char *) m)+(h)->size)==FENCE_TAG)
 
 static unsigned		alloc_count	= 0;
+
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,39)
+static DEFINE_SPINLOCK(stack_lock);
+#else
 static spinlock_t	track_lock	= SPIN_LOCK_UNLOCKED;
+#endif
 
 #if !defined (NDEBUG) && defined (LOG_TIMER)
 static struct timeval	zero_time;
@@ -531,7 +536,11 @@ int lock_init (lock_t * plock) {
 		ERROR("Could not allocate lock structure!!!\n");
 		return 0;
 	}
+#if LINUX_VERSION_CODE >= KERNEL_VERSION(2,6,39)
+	spin_lock_init(&tmp->lock);
+#else
 	tmp->lock = SPIN_LOCK_UNLOCKED;
+#endif
 	*plock = tmp;
 	return 1;
 } /* lock_init */
